@@ -28,6 +28,10 @@ ENV_ROLE_ARN = "TENCENTCLOUD_ROLE_ARN"
 ENV_ROLE_SESSION_NAME = "TENCENTCLOUD_ROLE_SESSION_NAME"
 ENV_REGION = "TENCENTCLOUD_REGION"
 ENV_TOKEN = "TENCENTCLOUD_TOKEN"
+ENV_TKE_REGION = "TKE_REGION"
+ENV_TKE_PROVIDER_ID = "TKE_PROVIDER_ID"
+ENV_TKE_IDENTITY_TOKEN_FILE = "TKE_IDENTITY_TOKEN_FILE"
+ENV_TKE_ROLE_ARN = "TKE_ROLE_ARN"
 
 Help = "help"
 CliVersion = "version"
