@@ -96,6 +96,9 @@ SERVICE_VERSIONS = {
     "bmvpc": [
         "2018-06-25"
     ],
+    "bpaas": [
+        "2018-12-17"
+    ],
     "bri": [
         "2019-03-28"
     ],
@@ -177,6 +180,9 @@ SERVICE_VERSIONS = {
     "cloudhsm": [
         "2019-11-12"
     ],
+    "cloudstudio": [
+        "2021-05-24"
+    ],
     "cls": [
         "2020-10-16"
     ],
@@ -369,6 +375,9 @@ SERVICE_VERSIONS = {
     "kms": [
         "2019-01-18"
     ],
+    "lcic": [
+        "2022-08-17"
+    ],
     "lighthouse": [
         "2020-03-24"
     ],
@@ -569,11 +578,15 @@ SERVICE_VERSIONS = {
     "tdmq": [
         "2020-02-17"
     ],
+    "tds": [
+        "2022-08-01"
+    ],
     "tem": [
         "2021-07-01",
         "2020-12-21"
     ],
     "teo": [
+        "2022-09-01",
         "2022-01-06"
     ],
     "thpc": [
